@@ -19,11 +19,11 @@ Template::Flute - Modern designer-friendly HTML templating Engine
 
 =head1 VERSION
 
-Version 0.0120
+Version 0.0121
 
 =cut
 
-our $VERSION = '0.0120';
+our $VERSION = '0.0121';
 
 =head1 SYNOPSIS
 
@@ -846,6 +846,19 @@ sub _replace_record {
 		#return undef if ((not defined $rep_str) and (defined $value->{target}));
 		$raw = $rep_str;
 		
+        if (my $skiptype = $value->{skip}) {
+        # placeholder for future options
+            if ($skiptype eq 'empty') {
+                if (!defined($rep_str) or
+                    $rep_str =~ m/^\s*$/s) {
+                    # do nothing
+                    return;
+                }
+            } else {
+                die "Wrong skip type $skiptype";
+            }
+        }
+
 		if (exists $value->{op}) {
             if ($value->{op} eq 'toggle' && ! $value->{target}) {
                 if (exists $value->{args} && $value->{args} eq 'static') {
@@ -1505,6 +1518,27 @@ is usually more convenient.
 
 =item i18n
 
+=item skip
+
+This attribute (which can be provided to C<param> or C<value>
+specification elements) supports the following values:
+
+=over 4
+
+=item empty
+
+Do not replace the template string if the value or parameter is
+undefined, empty or just whitespace.
+
+E.g.
+
+ <value name="cartline" skip="empty"/>
+ <list name="items" iterator="items">
+   <param name="category" skip="empty"/>
+ </list>
+
+=back
+
 =item pattern
 
 You can define patterns in your specification to I<interpolate> the
@@ -1966,7 +2000,7 @@ L<http://search.cpan.org/dist/Template-Flute/>
 
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to David Previous (bigpresh) for writing a much clearer introduction for
+Thanks to David Precious (bigpresh) for writing a much clearer introduction for
 Template::Flute.
 
 Thanks to Grega Pompe for proper implementation of nested lists and
